import pandas as _pd
from datas.navs import robo_exrate as _re, robo_fund_navs as _navs
from datas import datum as _datum, DatumType
from utils import config, to_bool
from datetime import timedelta

navs_config = config['datas']['navs'] if 'datas' in config and 'navs' in config['datas'] else {}


def get_navs(fund_id=None, min_date=None, max_date=None):
    navs = _navs.get_navs(fund_id=fund_id, min_date=min_date, max_date=max_date)
    if 'exrate' in navs_config:
        navs = _pd.DataFrame(navs)
        navs = navs.pivot_table(index='nav_date', columns='fund_id', values='nav_cal')
        for exrate_config in navs_config['exrate']:
            exrate = _pd.DataFrame(_re.get_exrates(ticker=exrate_config['ticker'], min_date=navs.index.min(), max_date=navs.index.max()))
            exrate = exrate[['date', 'close']]
            exrate.set_index('date', inplace=True)
            for fund in _datum.get_fund_datums(crncy=exrate_config['from']):
                navs[fund['id']] = round(navs[fund['id']] * exrate['close'], 4)
        navs = navs.reset_index().melt(id_vars='nav_date', value_name='nav_cal')
        navs.dropna(inplace=True)
        navs = navs[['fund_id', 'nav_date', 'nav_cal']]
        navs.sort_values('fund_id', inplace=True)
        navs = navs.to_dict('records')
    return navs


if __name__ == '__main__':
    from utils import parse_date

    print(get_navs(min_date=parse_date('2022-11-01')))
